@@ -467,7 +467,7 @@ class Reader
       if lines_to_restore.respond_to? :reverse
         @lines.push(*lines_to_restore.reverse)
       else
-        lines_to_restore.reverse_each {|it| @lines.push it }
+        lines_to_restore.reverse_each {|l| @lines.push l }
       end
       nil
     end
@@ -619,7 +619,7 @@ class PreprocessorReader < Reader
 
   # Public: Initialize the PreprocessorReader object
   def initialize document, data = nil, cursor = nil, opts = {}
-    @document = document
+    @sourcemap = (@document = document).sourcemap
     super data, cursor, opts
     if (default_include_depth = (document.attributes['max-include-depth'] || 64).to_i) > 0
       # track absolute max depth, current max depth for comparing to include stack size, and relative max depth for reporting
@@ -657,6 +657,11 @@ class PreprocessorReader < Reader
     if (line = super)
       line
     elsif @include_stack.empty?
+      end_cursor = nil
+      @conditional_stack.delete_if do |conditional|
+        logger.error message_with_context %(detected unterminated preprocessor conditional directive: #{conditional[:name]}::#{conditional[:target] || ''}[#{conditional[:expr] || ''}]), source_location: conditional[:source_location] || (end_cursor ||= cursor_at_prev_line)
+        true
+      end
       nil
     else
       pop_include
@@ -820,6 +825,10 @@ class PreprocessorReader < Reader
     return line unless @process_lines
 
     if line.empty?
+      if @skipping
+        shift
+        return
+      end
       @look_ahead += 1
       return line
     end
@@ -886,7 +895,7 @@ class PreprocessorReader < Reader
   # preprocessing recursively until the next line of available content is
   # found.
   #
-  # keyword   - The conditional inclusion directive (ifdef, ifndef, ifeval, endif)
+  # name      - The name of the conditional inclusion directive (ifdef, ifndef, ifeval, endif)
   # target    - The target, which is the name of one or more attributes that are
   #             used in the condition (blank in the case of the ifeval directive)
   # delimiter - The conditional delimiter for multiple attributes ('+' means all
@@ -897,27 +906,32 @@ class PreprocessorReader < Reader
   #             ifndef directives, and for the conditional expression for the ifeval directive.
   #
   # Returns a Boolean indicating whether the cursor should be advanced
-  def preprocess_conditional_directive keyword, target, delimiter, text
+  def preprocess_conditional_directive name, target, delimiter, text
     # attributes are case insensitive
     target = target.downcase unless (no_target = target.empty?)
 
-    if keyword == 'endif'
+    if name == 'endif'
       if text
         logger.error message_with_context %(malformed preprocessor directive - text not permitted: endif::#{target}[#{text}]), source_location: cursor
       elsif @conditional_stack.empty?
         logger.error message_with_context %(unmatched preprocessor directive: endif::#{target}[]), source_location: cursor
-      elsif no_target || target == (pair = @conditional_stack[-1])[:target]
+      elsif no_target || target == @conditional_stack[-1][:target]
         @conditional_stack.pop
         @skipping = @conditional_stack.empty? ? false : @conditional_stack[-1][:skipping]
       else
-        logger.error message_with_context %(mismatched preprocessor directive: endif::#{target}[], expected endif::#{pair[:target]}[]), source_location: cursor
+        logger.error message_with_context %(mismatched preprocessor directive: endif::#{target}[], expected endif::#{@conditional_stack[-1][:target] || ''}[]), source_location: cursor
       end
       return true
     elsif @skipping
+      if name === 'ifeval'
+        return true unless no_target && text && (EvalExpressionRx.match? text.strip)
+      elsif no_target
+        return true
+      end
       skip = false
     else
       # QUESTION any way to wrap ifdef & ifndef logic up together?
-      case keyword
+      case name
       when 'ifdef'
         if no_target
           logger.error message_with_context %(malformed preprocessor directive - missing target: ifdef::[#{text}]), source_location: cursor
@@ -926,10 +940,10 @@ class PreprocessorReader < Reader
         case delimiter
         when ','
           # skip if no attribute is defined
-          skip = target.split(',', -1).none? {|name| @document.attributes.key? name }
+          skip = target.split(',', -1).none? {|attr_name| @document.attributes.key? attr_name }
         when '+'
           # skip if any attribute is undefined
-          skip = target.split('+', -1).any? {|name| !@document.attributes.key? name }
+          skip = target.split('+', -1).any? {|attr_name| !@document.attributes.key? attr_name }
         else
           # if the attribute is undefined, then skip
           skip = !@document.attributes.key?(target)
@@ -942,10 +956,10 @@ class PreprocessorReader < Reader
         case delimiter
         when ','
           # skip if any attribute is defined
-          skip = target.split(',', -1).any? {|name| @document.attributes.key? name }
+          skip = target.split(',', -1).any? {|attr_name| @document.attributes.key? attr_name }
         when '+'
           # skip if all attributes are defined
-          skip = target.split('+', -1).all? {|name| @document.attributes.key? name }
+          skip = target.split('+', -1).all? {|attr_name| @document.attributes.key? attr_name }
         else
           # if the attribute is defined, then skip
           skip = @document.attributes.key?(target)
@@ -972,11 +986,11 @@ class PreprocessorReader < Reader
     end
 
     # conditional inclusion block
-    if keyword == 'ifeval' || !text
+    if name == 'ifeval'
       @skipping = true if skip
-      @conditional_stack << { target: target, skip: skip, skipping: @skipping }
+      @conditional_stack << { name: name, expr: text, skip: skip, skipping: @skipping, source_location: @sourcemap ? cursor : nil }
     # single line conditional inclusion
-    else
+    elsif text
       unless @skipping || skip
         replace_next_line text.rstrip
         # HACK push dummy line to stand in for the opening conditional directive that's subsequently dropped
@@ -985,6 +999,10 @@ class PreprocessorReader < Reader
         # QUESTION should we just call preprocess_include_directive here?
         @look_ahead -= 1 if text.start_with? 'include::'
       end
+    # conditional inclusion block
+    else
+      @skipping = true if skip
+      @conditional_stack << { name: name, target: target, skip: skip, skipping: @skipping, source_location: @sourcemap ? cursor : nil }
     end
 
     true
@@ -1039,9 +1057,9 @@ class PreprocessorReader < Reader
     # if running in SafeMode::SECURE or greater, don't process this directive
     # however, be friendly and at least make it a link to the source document
     elsif doc.safe >= SafeMode::SECURE
+      # FIXME we don't want to use a passthrough or link macro if we're in a verbatim context
       expanded_target = %(pass:c[#{expanded_target}]) if expanded_target.include? ' '
-      # FIXME we don't want to use a link macro if we are in a verbatim context
-      replace_next_line %(link:#{expanded_target}[role=include])
+      replace_next_line %(link:#{expanded_target}[#{(doc.attr? 'compat-mode') ? '' : 'role=include'}])
     elsif @maxdepth
       if @include_stack.size >= @maxdepth[:curr]
         logger.error message_with_context %(maximum include depth of #{@maxdepth[:rel]} exceeded), source_location: cursor
@@ -1240,17 +1258,11 @@ class PreprocessorReader < Reader
     doc = @document
     if (Helpers.uriish? target) || (::String === @dir ? nil : (target = %(#{@dir}/#{target})))
       unless doc.attr? 'allow-uri-read'
+       # FIXME we don't want to use a passthrough or link macro if we're in a verbatim context
         target = %(pass:c[#{target}]) if target.include? ' '
-        return replace_next_line %(link:#{target}[role=include])
-      end
-      if doc.attr? 'cache-uri'
-        # caching requires the open-uri-cached gem to be installed
-        # processing will be automatically aborted if these libraries can't be opened
-        Helpers.require_library 'open-uri/cached', 'open-uri-cached' unless defined? ::OpenURI::Cache
-      elsif !RUBY_ENGINE_OPAL
-        # autoload open-uri
-        ::OpenURI
+        return replace_next_line %(link:#{target}[#{(doc.attr? 'compat-mode') ? '' : 'role=include'}])
       end
+      Helpers.require_open_uri doc.attr? 'cache-uri'
       [(::URI.parse target), :uri, target]
     else
       # include file is resolved relative to dir of current include, or base_dir if within original docfile
