@@ -465,6 +465,7 @@ context 'Extensions' do
       assert_equal 1, extensions.size
       assert_kind_of Asciidoctor::Extensions::ProcessorExtension, extensions.first
       assert_kind_of SamplePreprocessor, extensions.first.instance
+      refute extensions.first.instance.frozen?
       assert_kind_of Method, extensions.first.process_method
     end
 
@@ -477,6 +478,7 @@ context 'Extensions' do
       assert_equal 1, extensions.size
       assert_kind_of Asciidoctor::Extensions::ProcessorExtension, extensions.first
       assert_kind_of SampleIncludeProcessor, extensions.first.instance
+      refute extensions.first.instance.frozen?
       assert_kind_of Method, extensions.first.process_method
     end
 
@@ -490,6 +492,7 @@ context 'Extensions' do
       assert_equal 1, extensions.size
       assert_kind_of Asciidoctor::Extensions::ProcessorExtension, extensions.first
       assert_kind_of SampleDocinfoProcessor, extensions.first.instance
+      refute extensions.first.instance.frozen?
       assert_kind_of Method, extensions.first.process_method
     end
 
@@ -503,6 +506,7 @@ context 'Extensions' do
       assert_equal 1, extensions.size
       assert_kind_of Asciidoctor::Extensions::ProcessorExtension, extensions.first
       assert_kind_of SampleTreeprocessor, extensions.first.instance
+      refute extensions.first.instance.frozen?
       assert_kind_of Method, extensions.first.process_method
     end
 
@@ -515,6 +519,7 @@ context 'Extensions' do
       assert_equal 1, extensions.size
       assert_kind_of Asciidoctor::Extensions::ProcessorExtension, extensions.first
       assert_kind_of SamplePostprocessor, extensions.first.instance
+      refute extensions.first.instance.frozen?
       assert_kind_of Method, extensions.first.process_method
     end
 
@@ -527,6 +532,7 @@ context 'Extensions' do
       extension = registry.find_block_extension :sample
       assert_kind_of Asciidoctor::Extensions::ProcessorExtension, extension
       assert_kind_of SampleBlock, extension.instance
+      refute extension.instance.frozen?
       assert_kind_of Method, extension.process_method
     end
 
@@ -1054,8 +1060,41 @@ context 'Extensions' do
     test 'should log debug message if custom block macro is unknown' do
       input = 'unknown::[]'
       using_memory_logger Logger::Severity::DEBUG do |logger|
-        convert_string_to_embedded input
+        result = convert_string_to_embedded input
         assert_message logger, :DEBUG, '<stdin>: line 1: unknown name for block macro: unknown', Hash
+        assert_xpath %(/*[@class="paragraph"]/p[text()="#{input}"]), result, 1
+      end
+    end
+
+    test 'should log debug message if custom block macro is unknown when custom block macros are registered' do
+      begin
+        input = 'unknown::[]'
+        Asciidoctor::Extensions.register do
+          block_macro SampleBlockMacro, :sample
+        end
+        using_memory_logger Logger::Severity::DEBUG do |logger|
+          result = convert_string_to_embedded input
+          assert_message logger, :DEBUG, '<stdin>: line 1: unknown name for block macro: unknown', Hash
+          assert_xpath %(/*[@class="paragraph"]/p[text()="#{input}"]), result, 1
+        end
+      ensure
+        Asciidoctor::Extensions.unregister_all
+      end
+    end
+
+    test 'should not log debug message if line is not a custom block macro and block macros are registered' do
+      begin
+        input = '* xref:component::page.adoc[link text]'
+        Asciidoctor::Extensions.register do
+          block_macro SampleBlockMacro, :sample
+        end
+        using_memory_logger Logger::Severity::DEBUG do |logger|
+          result = convert_string_to_embedded input
+          assert_empty logger.messages
+          assert_css 'ul li a[href="component::page.html"]', result, 1
+        end
+      ensure
+        Asciidoctor::Extensions.unregister_all
       end
     end
 
