@@ -316,7 +316,7 @@ context 'Manpage' do
 	foi escolhida. Isso é feito apenas para picaretas de cereja sem conflitos.
 	EOS
       output = Asciidoctor.convert input, backend: :manpage
-      assert_equal '\&...', output.lines[-3][0..4].chomp
+      assert_equal '\&.\|.\|.', (output.lines[-3].partition ')')[0]
     end
 
     test 'should not escape ellipsis in the middle of a line' do
@@ -331,7 +331,22 @@ context 'Manpage' do
 	de cereja sem conflitos.
 	EOS
       output = Asciidoctor.convert input, backend: :manpage
-      assert(output.lines[-5].include? 'commit...')
+      assert_include 'commit.\|.\|.', output.lines[-5]
+    end
+
+    test 'should not space dots that are not meant to be an ellipsis' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      -x::
+      Ao gravar o commit, acrescente uma linha que diz
+      "(cherry picked from commit\\...)" à mensagem de commit
+      original para indicar qual commit esta mudança
+      foi escolhida. Isso é feito apenas para picaretas
+      de cereja sem conflitos.
+      EOS
+      output = Asciidoctor.convert input, backend: :manpage
+      assert_include 'commit...', output.lines[-5]
     end
 
     test 'should normalize whitespace in a paragraph' do
@@ -972,7 +987,7 @@ context 'Manpage' do
       .SH "SYNOPSIS"
       .sp
       .nf
-      \fIcommand\fP [\fIOPTION\fP]... \fIFILE\fP...
+      \fIcommand\fP [\fIOPTION\fP].\|.\|. \fIFILE\fP.\|.\|.
       .fi
       .br
       .SH "DESCRIPTION"
