@@ -379,6 +379,33 @@ context "Parser" do
     assert_equal 'JCVD', doc.attributes['authorinitials']
   end
 
+  test 'use implicit authors if value of authors attribute matches computed value' do
+    input = <<~'EOS'
+    Doc Writer; Junior Writer
+    :authors: Doc Writer, Junior Writer
+    EOS
+    doc = empty_document
+    parse_header_metadata input, doc
+    assert_equal 'Doc Writer, Junior Writer', doc.attributes['authors']
+    assert_equal 'Doc Writer', doc.attributes['author_1']
+    assert_equal 'Junior Writer', doc.attributes['author_2']
+  end
+
+  test 'replace implicit authors if value of authors attribute does not match computed value' do
+    input = <<~'EOS'
+    Doc Writer; Junior Writer
+    :authors: Stuart Rackham; Dan Allen; Sarah White
+    EOS
+    doc = empty_document
+    metadata, _ = parse_header_metadata input, doc
+    assert_equal 3, metadata['authorcount']
+    assert_equal 3, doc.attributes['authorcount']
+    assert_equal 'Stuart Rackham, Dan Allen, Sarah White', doc.attributes['authors']
+    assert_equal 'Stuart Rackham', doc.attributes['author_1']
+    assert_equal 'Dan Allen', doc.attributes['author_2']
+    assert_equal 'Sarah White', doc.attributes['author_3']
+  end
+
   test 'sets authorcount to 0 if document has no authors' do
     input = ''
     doc = empty_document
@@ -387,6 +414,11 @@ context "Parser" do
     assert_equal 0, metadata['authorcount']
   end
 
+  test 'returns empty hash if document has no authors and invoked without document' do
+    metadata, _ = parse_header_metadata ''
+    assert_empty metadata
+  end
+
   test 'does not drop name joiner when using multiple authors' do
     input = 'Kismet Chameleon; Lazarus het_Draeke'
     doc = empty_document
